#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# === This file is part of Calamares - <http://github.com/calamares> ===
#
#   Copyright 2017-2020, Philip Müller <philm@manjaro.org>
#
#   Calamares is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   Calamares is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with Calamares. If not, see <http://www.gnu.org/licenses/>.

from libcalamares.utils import target_env_call
from os.path import exists


class CleanupOem:
    def remove_pkg(self, pkg, path):
        if exists(path):
            target_env_call(['pacman', '-Rsn', '--noconfirm', pkg])

    def run(self):
        if exists('/etc/sudoers.d/g_oem'):
            target_env_call(['rm', '/etc/sudoers.d/g_oem'])
        self.remove_pkg("calamares-oem-modules", "/etc/calamares/modules/welcome.conf")
        self.remove_pkg("calamares-oem-sx-settings", "/etc/oemskel/.spitfire")
        self.remove_pkg("calamares-oem-beelink-gnome-settings", "/etc/oemskel/.beelink-gnome")
        self.remove_pkg("calamares-oem-bldbk-kde-settings", "/etc/oemskel/.bladebook")
        self.remove_pkg("calamares-oem-bldbk-xfce-settings", "/etc/oemskel/.bladebook-xfce")
        self.remove_pkg("calamares-oem-bldbk-gnome-settings", "/etc/oemskel/.bladebook-gnome")
        self.remove_pkg("calamares-oem-bldbk-cinnamon-settings", "/etc/oemskel/.bladebook-cinnamon")
        self.remove_pkg("calamares-oem-bldbk-i3-settings", "/etc/oemskel/.bladebook-i3")
        self.remove_pkg("calamares-oem-infbk14-xfce-settings", "/etc/oemskel/.infinitybook14-xfce")
        self.remove_pkg("calamares-oem-infbkpro-xfce-settings", "/etc/oemskel/.infinitybookpro-xfce")
        self.remove_pkg("calamares-oem-infbk14-kde-settings", "/etc/oemskel/.infinitybook14-kde")
        self.remove_pkg("calamares-oem-infbkpro-kde-settings", "/etc/oemskel/.infinitybookpro-kde")
        self.remove_pkg("calamares-oem-starlabs-gnome-settings", "/etc/oemskel/.starlabs-gnome")
        self.remove_pkg("calamares-oem-starlabs-kde-settings", "/etc/oemskel/.starlabs-kde")
        self.remove_pkg("calamares-oem-starlabs-xfce-settings", "/etc/oemskel/.starlabs-xfce")
        self.remove_pkg("calamares-oem-xfce-settings", "/etc/oemskel/.xfce")

        return None


def run():
    """ Cleanup OEM files """

    oem = CleanupOem()

    return oem.run()

